use crate::types::{enums::time_metrics::TimeMetrics, traits::countable_interface::ICountable};

pub struct CountableTime(i64, i64);

impl ICountable<(i64, i64), TimeMetrics> for CountableTime {
    #[inline]
    fn new() -> Self {
        Self(0, 0)
    }

    #[inline]
    fn from_value(value: i64) -> Self {
        Self((value / 10) % 10, value % 10)
    }

    #[inline]
    fn get_values(&self) -> (i64, i64) {
        (self.0, self.1)
    }

    #[inline]
    fn set_values(&self, value: i64) -> Self {
        Self((value / 10) % 10, value % 10)
    }

    fn get_postfix(&self, metrics: TimeMetrics) -> Option<String> {
        let all_word_declensions = metrics.get_word_declensions();
        let (first, second, third): (String, String, String) = (
            all_word_declensions.0.into(),
            all_word_declensions.1.into(),
            all_word_declensions.2.into(),
        );

        match self.get_values() {
            (0, 1) | (2..=9, 1) => Some(first),
            (0, 2..=4) | (2..=9, 2..=4) => Some(second),
            (0..=9, 0) | (0, 5..=9) | (1, 0..=9) | (2..=9, 5..=9) => Some(third),
            _ => None,
        }
    }
}
